@@ -10,16 +10,30 @@ use warnings;
 use parent 'Plack::Middleware';
 
 use Plack::Util;
-use Plack::Util::Accessor qw/ filter /;
-use HTTP::Status          qw/ is_success /;
+use Plack::Util::Accessor qw/ filter callback /;
+use HTTP::Status ();
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 
+sub prepare_app {
+    my ($self) = @_;
+
+    unless (defined $self->callback) {
+
+        $self->callback( sub {
+            my ($res) = @_;
+            Plack::Util::header_set( $res->[1], 'allow', "GET, HEAD, OPTIONS" );
+        });
+
+    }
+}
+
 sub call {
     my ( $self, $env ) = @_;
 
     my $filter = $self->filter;
+    my $callback = $self->callback;
 
     if ( $env->{REQUEST_METHOD} eq "OPTIONS" && ( !$filter || $filter->($env) ) ) {
 
@@ -29,10 +43,9 @@ sub call {
             $res,
             sub {
                 my ($res) = @_;
-                if ( is_success($res->[0]) ) {
-                    Plack::Util::header_set( $res->[1], 'allow', "GET, HEAD, OPTIONS" );
+                if ( HTTP::Status::is_success($res->[0]) ) {
+                    $callback->( $res, $env );
                 }
-                return;
             }
         );
 
@@ -59,7 +72,7 @@ Plack::Middleware::EmulateOPTIONS - handle OPTIONS requests as HEAD
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -81,7 +94,7 @@ version v0.1.1
 
 This middleware adds support for handling HTTP C<OPTIONS> requests, by internally rewriting them as C<HEAD> requests.
 
-If the requests succeed, then it will add C<Allow> headers set to C<GET, HEAD, OPTIONS> to the responses.
+If the requests succeed, then it will add C<Allow> headers using the L</callback> method.
 
 If the requests do not succeed, then the responses are passed unchanged.
 
@@ -94,10 +107,37 @@ You can add the L</filter> attribute to determine whether it will proxy C<HEAD>
 This is an optional code reference for a function that takes the L<PSGI> environment and returns true or false as to
 whether the request should be proxied.
 
-For instance, if you have CORS handler for a specific path, you might return false for those requests.
+For instance, if you have CORS handler for a specific path, you might return false for those requests. Alternatively,
+you might use the L</callback>.
 
 If you need a different value for the C<Allow> headers, then you should handle the requests separately.
 
+=head2 callback
+
+This is an optional code reference that modifies the response headers.
+
+By default, it sets the C<Allow> header to "GET, HEAD, OPTIONS".
+
+If you override this, then you will need to manually set the header yourself, for example:
+
+    use Plack::Util;
+
+    enable "EmulateOPTIONS",
+      callback => sub {
+          my $res = shift;
+          my $env = shift;
+
+          my @allowed = qw( GET HEAD OPTIONS );
+          if ( $env->{PATH_INFO} =~ m[^/api/] ) {
+             push @allowed, qw( POST PUT DELETE );
+          }
+
+          Plack::Util::header_set( $res->[1], 'allow', join(", ", @allowed) );
+
+        };
+
+This was added in v0.2.0.
+
 =head1 SEE ALSO
 
 L<Plack>
